package com.xunmei.system.service;

import java.util.List;

import com.xunmei.system.domain.SysWorkTimeSetDayofweek;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.xunmei.common.core.web.page.TableDataInfo;

/**
 * 【作息】Service接口
 *
 * @author xunmei
 * @date 2023-08-15
 */
public interface ISysWorkTimeSetDayofweekService extends IService<SysWorkTimeSetDayofweek> {
    /**
     * 查询【作息】
     *
     * @param id 【作息】主键
     * @return 【作息】
     */
    SysWorkTimeSetDayofweek selectSysWorkTimeSetDayofweekById(Long id);

    /**
     * 查询【作息】列表
     *
     * @param sysWorkTimeSetDayofweek 【作息】
     * @return 【作息】集合
     */
    List<SysWorkTimeSetDayofweek> selectSysWorkTimeSetDayofweekList(SysWorkTimeSetDayofweek sysWorkTimeSetDayofweek);

    /**
     * 新增【作息】
     *
     * @param sysWorkTimeSetDayofweek 【作息】
     * @return 结果
     */
    int insertSysWorkTimeSetDayofweek(SysWorkTimeSetDayofweek sysWorkTimeSetDayofweek);

    /**
     * 修改【作息】
     *
     * @param sysWorkTimeSetDayofweek 【作息】
     * @return 结果
     */
    int updateSysWorkTimeSetDayofweek(SysWorkTimeSetDayofweek sysWorkTimeSetDayofweek);

    /**
     * 批量删除【作息】
     *
     * @param ids 需要删除的【作息】主键集合
     * @return 结果
     */
    int deleteSysWorkTimeSetDayofweekByIds(Long[] ids);

    /**
     * 删除【作息】信息
     *
     * @param id 【作息】主键
     * @return 结果
     */
    int deleteSysWorkTimeSetDayofweekById(Long id);

    /**
     * 查询【作息】分页数据
     *
     * @param sysWorkTimeSetDayofweek 查询条件对象
     * @return Page
     */
    TableDataInfo<SysWorkTimeSetDayofweek> selectPage(SysWorkTimeSetDayofweek sysWorkTimeSetDayofweek);
}
