package com.xunmei.system.mapper;

import java.util.List;

import com.xunmei.system.domain.SysWorkTimeSetDayofweek;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author xunmei
 * @date 2023-08-15
 */
public interface SysWorkTimeSetDayofweekMapper extends BaseMapper<SysWorkTimeSetDayofweek> {
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
     SysWorkTimeSetDayofweek selectSysWorkTimeSetDayofweekById(Long id);
    List<SysWorkTimeSetDayofweek> findByWorkTimeSetIdIn(List<Long> ids);
    /**
     * 查询【请填写功能名称】列表
     *
     * @param sysWorkTimeSetDayofweek 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
     List<SysWorkTimeSetDayofweek> selectSysWorkTimeSetDayofweekList(SysWorkTimeSetDayofweek sysWorkTimeSetDayofweek);

    /**
     * 新增【请填写功能名称】
     *
     * @param sysWorkTimeSetDayofweek 【请填写功能名称】
     * @return 结果
     */
     int insertSysWorkTimeSetDayofweek(SysWorkTimeSetDayofweek sysWorkTimeSetDayofweek);

    /**
     * 修改【请填写功能名称】
     *
     * @param sysWorkTimeSetDayofweek 【请填写功能名称】
     * @return 结果
     */
     int updateSysWorkTimeSetDayofweek(SysWorkTimeSetDayofweek sysWorkTimeSetDayofweek);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
     int deleteSysWorkTimeSetDayofweekById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteSysWorkTimeSetDayofweekByIds(Long[] ids);
}
